summaryrefslogtreecommitdiffstats
path: root/src/widgets
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:04:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:04:08 -0600
commite02e31c8b9d854cd62cbe9799228f6e08e882773 (patch)
tree53303c981d0b20e03c5a2fc8e959fa74adcb90d1 /src/widgets
parent143f194af098d44bf0dd1ebb29e59f30ce48d523 (diff)
downloadtqt3-e02e31c8b9d854cd62cbe9799228f6e08e882773.tar.gz
tqt3-e02e31c8b9d854cd62cbe9799228f6e08e882773.zip
Sync with latest script
Diffstat (limited to 'src/widgets')
-rw-r--r--src/widgets/qaction.cpp4
-rw-r--r--src/widgets/qaction.h2
-rw-r--r--src/widgets/qbutton.cpp2
-rw-r--r--src/widgets/qbutton.h2
-rw-r--r--src/widgets/qbuttongroup.cpp2
-rw-r--r--src/widgets/qbuttongroup.h2
-rw-r--r--src/widgets/qcheckbox.cpp2
-rw-r--r--src/widgets/qcheckbox.h2
-rw-r--r--src/widgets/qcombobox.cpp2
-rw-r--r--src/widgets/qcombobox.h2
-rw-r--r--src/widgets/qdatetimeedit.cpp2
-rw-r--r--src/widgets/qdatetimeedit.h2
-rw-r--r--src/widgets/qdial.cpp2
-rw-r--r--src/widgets/qdial.h2
-rw-r--r--src/widgets/qdialogbuttons.cpp2
-rw-r--r--src/widgets/qdialogbuttons_p.h2
-rw-r--r--src/widgets/qdockarea.cpp4
-rw-r--r--src/widgets/qdockarea.h2
-rw-r--r--src/widgets/qdockwindow.cpp8
-rw-r--r--src/widgets/qdockwindow.h2
-rw-r--r--src/widgets/qeffects.cpp2
-rw-r--r--src/widgets/qeffects_p.h2
-rw-r--r--src/widgets/qframe.cpp2
-rw-r--r--src/widgets/qframe.h2
-rw-r--r--src/widgets/qgrid.cpp2
-rw-r--r--src/widgets/qgrid.h2
-rw-r--r--src/widgets/qgridview.cpp2
-rw-r--r--src/widgets/qgridview.h2
-rw-r--r--src/widgets/qgroupbox.cpp2
-rw-r--r--src/widgets/qgroupbox.h2
-rw-r--r--src/widgets/qhbox.cpp2
-rw-r--r--src/widgets/qhbox.h2
-rw-r--r--src/widgets/qhbuttongroup.cpp2
-rw-r--r--src/widgets/qhbuttongroup.h2
-rw-r--r--src/widgets/qheader.cpp2
-rw-r--r--src/widgets/qheader.h2
-rw-r--r--src/widgets/qhgroupbox.cpp2
-rw-r--r--src/widgets/qhgroupbox.h2
-rw-r--r--src/widgets/qlabel.cpp2
-rw-r--r--src/widgets/qlabel.h2
-rw-r--r--src/widgets/qlcdnumber.cpp2
-rw-r--r--src/widgets/qlcdnumber.h2
-rw-r--r--src/widgets/qlineedit.cpp30
-rw-r--r--src/widgets/qlineedit.h2
-rw-r--r--src/widgets/qlistbox.cpp10
-rw-r--r--src/widgets/qlistbox.h2
-rw-r--r--src/widgets/qlistview.cpp8
-rw-r--r--src/widgets/qlistview.h2
-rw-r--r--src/widgets/qmainwindow.cpp4
-rw-r--r--src/widgets/qmainwindow.h2
-rw-r--r--src/widgets/qmenubar.cpp4
-rw-r--r--src/widgets/qmenubar.h2
-rw-r--r--src/widgets/qmenudata.cpp2
-rw-r--r--src/widgets/qmenudata.h2
-rw-r--r--src/widgets/qmultilineedit.cpp4
-rw-r--r--src/widgets/qmultilineedit.h2
-rw-r--r--src/widgets/qpopupmenu.cpp4
-rw-r--r--src/widgets/qpopupmenu.h2
-rw-r--r--src/widgets/qprogressbar.cpp2
-rw-r--r--src/widgets/qprogressbar.h2
-rw-r--r--src/widgets/qpushbutton.cpp2
-rw-r--r--src/widgets/qpushbutton.h2
-rw-r--r--src/widgets/qradiobutton.cpp2
-rw-r--r--src/widgets/qradiobutton.h2
-rw-r--r--src/widgets/qrangecontrol.cpp2
-rw-r--r--src/widgets/qrangecontrol.h2
-rw-r--r--src/widgets/qscrollbar.cpp2
-rw-r--r--src/widgets/qscrollbar.h2
-rw-r--r--src/widgets/qscrollview.cpp2
-rw-r--r--src/widgets/qscrollview.h2
-rw-r--r--src/widgets/qslider.cpp2
-rw-r--r--src/widgets/qslider.h2
-rw-r--r--src/widgets/qspinbox.cpp2
-rw-r--r--src/widgets/qspinbox.h2
-rw-r--r--src/widgets/qspinwidget.cpp2
-rw-r--r--src/widgets/qsplashscreen.cpp2
-rw-r--r--src/widgets/qsplashscreen.h2
-rw-r--r--src/widgets/qsplitter.cpp2
-rw-r--r--src/widgets/qsplitter.h2
-rw-r--r--src/widgets/qstatusbar.cpp2
-rw-r--r--src/widgets/qstatusbar.h2
-rw-r--r--src/widgets/qsyntaxhighlighter.cpp4
-rw-r--r--src/widgets/qsyntaxhighlighter.h2
-rw-r--r--src/widgets/qsyntaxhighlighter_p.h2
-rw-r--r--src/widgets/qtabbar.cpp2
-rw-r--r--src/widgets/qtabbar.h2
-rw-r--r--src/widgets/qtabwidget.cpp2
-rw-r--r--src/widgets/qtabwidget.h2
-rw-r--r--src/widgets/qtextbrowser.cpp2
-rw-r--r--src/widgets/qtextbrowser.h2
-rw-r--r--src/widgets/qtextedit.cpp6
-rw-r--r--src/widgets/qtextedit.h2
-rw-r--r--src/widgets/qtextview.cpp2
-rw-r--r--src/widgets/qtextview.h2
-rw-r--r--src/widgets/qtitlebar.cpp2
-rw-r--r--src/widgets/qtitlebar_p.h2
-rw-r--r--src/widgets/qtoolbar.cpp2
-rw-r--r--src/widgets/qtoolbar.h2
-rw-r--r--src/widgets/qtoolbox.cpp2
-rw-r--r--src/widgets/qtoolbox.h2
-rw-r--r--src/widgets/qtoolbutton.cpp2
-rw-r--r--src/widgets/qtoolbutton.h2
-rw-r--r--src/widgets/qtooltip.cpp4
-rw-r--r--src/widgets/qtooltip.h2
-rw-r--r--src/widgets/qvalidator.cpp4
-rw-r--r--src/widgets/qvalidator.h2
-rw-r--r--src/widgets/qvbox.cpp2
-rw-r--r--src/widgets/qvbox.h2
-rw-r--r--src/widgets/qvbuttongroup.cpp2
-rw-r--r--src/widgets/qvbuttongroup.h2
-rw-r--r--src/widgets/qvgroupbox.cpp2
-rw-r--r--src/widgets/qvgroupbox.h2
-rw-r--r--src/widgets/qwhatsthis.cpp2
-rw-r--r--src/widgets/qwhatsthis.h2
-rw-r--r--src/widgets/qwidgetinterface_p.h2
-rw-r--r--src/widgets/qwidgetplugin.cpp4
-rw-r--r--src/widgets/qwidgetplugin.h2
-rw-r--r--src/widgets/qwidgetresizehandler.cpp2
-rw-r--r--src/widgets/qwidgetresizehandler_p.h2
-rw-r--r--src/widgets/qwidgetstack.cpp2
-rw-r--r--src/widgets/qwidgetstack.h2
121 files changed, 157 insertions, 157 deletions
diff --git a/src/widgets/qaction.cpp b/src/widgets/qaction.cpp
index 025609b2..645e8e58 100644
--- a/src/widgets/qaction.cpp
+++ b/src/widgets/qaction.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -785,7 +785,7 @@ void TQAction::setAccel( const TQKeySequence& key )
}
#if defined(QT_CHECK_STATE)
else
- qWarning( "TQAction::setAccel() (%s) retquires widget in parent chain", name() );
+ qWarning( "TQAction::setAccel() (%s) requires widget in parent chain", name() );
#endif
d->update();
}
diff --git a/src/widgets/qaction.h b/src/widgets/qaction.h
index b8c04b13..6b227b3a 100644
--- a/src/widgets/qaction.h
+++ b/src/widgets/qaction.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qbutton.cpp b/src/widgets/qbutton.cpp
index 3cacc089..220dba2f 100644
--- a/src/widgets/qbutton.cpp
+++ b/src/widgets/qbutton.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qbutton.h b/src/widgets/qbutton.h
index 18048683..dceaa0f8 100644
--- a/src/widgets/qbutton.h
+++ b/src/widgets/qbutton.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qbuttongroup.cpp b/src/widgets/qbuttongroup.cpp
index 7e89b1da..b8aa7c85 100644
--- a/src/widgets/qbuttongroup.cpp
+++ b/src/widgets/qbuttongroup.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qbuttongroup.h b/src/widgets/qbuttongroup.h
index fa0b389e..edb28aeb 100644
--- a/src/widgets/qbuttongroup.h
+++ b/src/widgets/qbuttongroup.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qcheckbox.cpp b/src/widgets/qcheckbox.cpp
index 91c8ed42..7b63674f 100644
--- a/src/widgets/qcheckbox.cpp
+++ b/src/widgets/qcheckbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qcheckbox.h b/src/widgets/qcheckbox.h
index dfb5217b..7c0dc9df 100644
--- a/src/widgets/qcheckbox.h
+++ b/src/widgets/qcheckbox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qcombobox.cpp b/src/widgets/qcombobox.cpp
index 8923192a..1e12906f 100644
--- a/src/widgets/qcombobox.cpp
+++ b/src/widgets/qcombobox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qcombobox.h b/src/widgets/qcombobox.h
index 34995824..f3f073f6 100644
--- a/src/widgets/qcombobox.h
+++ b/src/widgets/qcombobox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qdatetimeedit.cpp b/src/widgets/qdatetimeedit.cpp
index 300db0ee..9f82aa51 100644
--- a/src/widgets/qdatetimeedit.cpp
+++ b/src/widgets/qdatetimeedit.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qdatetimeedit.h b/src/widgets/qdatetimeedit.h
index d50d0c43..f725149e 100644
--- a/src/widgets/qdatetimeedit.h
+++ b/src/widgets/qdatetimeedit.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qdial.cpp b/src/widgets/qdial.cpp
index e4114052..b7736f5e 100644
--- a/src/widgets/qdial.cpp
+++ b/src/widgets/qdial.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qdial.h b/src/widgets/qdial.h
index 036c8195..e171a6b0 100644
--- a/src/widgets/qdial.h
+++ b/src/widgets/qdial.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qdialogbuttons.cpp b/src/widgets/qdialogbuttons.cpp
index cd831be7..d87288dc 100644
--- a/src/widgets/qdialogbuttons.cpp
+++ b/src/widgets/qdialogbuttons.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qdialogbuttons_p.h b/src/widgets/qdialogbuttons_p.h
index 2f833637..6422eed9 100644
--- a/src/widgets/qdialogbuttons_p.h
+++ b/src/widgets/qdialogbuttons_p.h
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qdockarea.cpp b/src/widgets/qdockarea.cpp
index bb55db8b..767214c7 100644
--- a/src/widgets/qdockarea.cpp
+++ b/src/widgets/qdockarea.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -388,7 +388,7 @@ int TQDockAreaLayout::layoutItems( const TQRect &rect, bool testonly )
if ( pos + dockExtend > size_extent( r.size(), orientation() ) - 1 )
pos = TQMAX( op, size_extent( r.size(), orientation() ) - 1 - dockExtend );
}
- // do some calculations and add the remember the rect which the docking widget retquires for the placing
+ // do some calculations and add the remember the rect which the docking widget requires for the placing
TQRect dwRect(pos, sectionpos, dockExtend, dock_strut( dw, orientation() ) );
lastLine.append( DockData( dw, dwRect ) );
if ( ::qt_cast<TQToolBar*>(dw) )
diff --git a/src/widgets/qdockarea.h b/src/widgets/qdockarea.h
index 11f6795c..ca6391d7 100644
--- a/src/widgets/qdockarea.h
+++ b/src/widgets/qdockarea.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qdockwindow.cpp b/src/widgets/qdockwindow.cpp
index 5818fa40..82fba58a 100644
--- a/src/widgets/qdockwindow.cpp
+++ b/src/widgets/qdockwindow.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -612,7 +612,7 @@ void TQDockWindowTitleBar::mousePressEvent( TQMouseEvent *e )
ctrlDown = ( e->state() & ControlButton ) == ControlButton;
oldFocus = qApp->focusWidget();
// setFocus activates the window, which deactivates the main window
-// not what we want, and not retquired anyway on Windows
+// not what we want, and not required anyway on Windows
#ifndef Q_WS_WIN
setFocus();
#endif
@@ -630,7 +630,7 @@ void TQDockWindowTitleBar::mousePressEvent( TQMouseEvent *e )
offset = e->pos();
dockWindow->startRectDraw( mapToGlobal( e->pos() ), !opaque );
// grabMouse resets the Windows mouse press count, so we never receive a double click on Windows
-// not retquired on Windows, and did work on X11, too, but no problem there in the first place
+// not required on Windows, and did work on X11, too, but no problem there in the first place
#ifndef Q_WS_WIN
if(!oldPressed && dockWindow->opaqueMoving())
grabMouse();
@@ -1771,7 +1771,7 @@ void TQDockWindow::setFixedExtentHeight( int h )
\brief whether the dock window prefers to start a new line in the
dock area.
- The default is FALSE, i.e. the dock window doesn't retquire a new
+ The default is FALSE, i.e. the dock window doesn't require a new
line in the dock area.
*/
diff --git a/src/widgets/qdockwindow.h b/src/widgets/qdockwindow.h
index eb6daa20..57c66bc7 100644
--- a/src/widgets/qdockwindow.h
+++ b/src/widgets/qdockwindow.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qeffects.cpp b/src/widgets/qeffects.cpp
index 690a7cba..47393ac5 100644
--- a/src/widgets/qeffects.cpp
+++ b/src/widgets/qeffects.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qeffects_p.h b/src/widgets/qeffects_p.h
index ea7347e8..41de7721 100644
--- a/src/widgets/qeffects_p.h
+++ b/src/widgets/qeffects_p.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qframe.cpp b/src/widgets/qframe.cpp
index 1e3b3568..a820f6cb 100644
--- a/src/widgets/qframe.cpp
+++ b/src/widgets/qframe.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qframe.h b/src/widgets/qframe.h
index 4854012e..ae174974 100644
--- a/src/widgets/qframe.h
+++ b/src/widgets/qframe.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qgrid.cpp b/src/widgets/qgrid.cpp
index f3fecf4e..d0584418 100644
--- a/src/widgets/qgrid.cpp
+++ b/src/widgets/qgrid.cpp
@@ -14,7 +14,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qgrid.h b/src/widgets/qgrid.h
index 880e88a3..a1a6508c 100644
--- a/src/widgets/qgrid.h
+++ b/src/widgets/qgrid.h
@@ -14,7 +14,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qgridview.cpp b/src/widgets/qgridview.cpp
index 937cc56a..146c31b9 100644
--- a/src/widgets/qgridview.cpp
+++ b/src/widgets/qgridview.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qgridview.h b/src/widgets/qgridview.h
index 428ce48e..d3f3f8c5 100644
--- a/src/widgets/qgridview.h
+++ b/src/widgets/qgridview.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qgroupbox.cpp b/src/widgets/qgroupbox.cpp
index 0bdad68f..05f88387 100644
--- a/src/widgets/qgroupbox.cpp
+++ b/src/widgets/qgroupbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qgroupbox.h b/src/widgets/qgroupbox.h
index a293ab6e..ed95c5c6 100644
--- a/src/widgets/qgroupbox.h
+++ b/src/widgets/qgroupbox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qhbox.cpp b/src/widgets/qhbox.cpp
index b9375769..cda81fd9 100644
--- a/src/widgets/qhbox.cpp
+++ b/src/widgets/qhbox.cpp
@@ -14,7 +14,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qhbox.h b/src/widgets/qhbox.h
index cb388626..162fa3e6 100644
--- a/src/widgets/qhbox.h
+++ b/src/widgets/qhbox.h
@@ -14,7 +14,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qhbuttongroup.cpp b/src/widgets/qhbuttongroup.cpp
index 08da1a99..f8f48d95 100644
--- a/src/widgets/qhbuttongroup.cpp
+++ b/src/widgets/qhbuttongroup.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qhbuttongroup.h b/src/widgets/qhbuttongroup.h
index 91616ed0..8a6caff7 100644
--- a/src/widgets/qhbuttongroup.h
+++ b/src/widgets/qhbuttongroup.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qheader.cpp b/src/widgets/qheader.cpp
index 8e029ca7..6925d10d 100644
--- a/src/widgets/qheader.cpp
+++ b/src/widgets/qheader.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qheader.h b/src/widgets/qheader.h
index f88f7ba2..2f5d000e 100644
--- a/src/widgets/qheader.h
+++ b/src/widgets/qheader.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qhgroupbox.cpp b/src/widgets/qhgroupbox.cpp
index 098a5eac..b06061e0 100644
--- a/src/widgets/qhgroupbox.cpp
+++ b/src/widgets/qhgroupbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qhgroupbox.h b/src/widgets/qhgroupbox.h
index 3a4dedbc..9f61a4a3 100644
--- a/src/widgets/qhgroupbox.h
+++ b/src/widgets/qhgroupbox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qlabel.cpp b/src/widgets/qlabel.cpp
index d9b40015..73e913df 100644
--- a/src/widgets/qlabel.cpp
+++ b/src/widgets/qlabel.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qlabel.h b/src/widgets/qlabel.h
index ae2c6baa..8e1ba94f 100644
--- a/src/widgets/qlabel.h
+++ b/src/widgets/qlabel.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qlcdnumber.cpp b/src/widgets/qlcdnumber.cpp
index f9b956f7..4937c907 100644
--- a/src/widgets/qlcdnumber.cpp
+++ b/src/widgets/qlcdnumber.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qlcdnumber.h b/src/widgets/qlcdnumber.h
index b473e537..a872703b 100644
--- a/src/widgets/qlcdnumber.h
+++ b/src/widgets/qlcdnumber.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qlineedit.h b/src/widgets/qlineedit.h
index 808c087b..73db03d3 100644
--- a/src/widgets/qlineedit.h
+++ b/src/widgets/qlineedit.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qlistbox.h b/src/widgets/qlistbox.h
index 2f40a557..385e92b3 100644
--- a/src/widgets/qlistbox.h
+++ b/src/widgets/qlistbox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qlistview.cpp b/src/widgets/qlistview.cpp
index f537cc3b..7340bf35 100644
--- a/src/widgets/qlistview.cpp
+++ b/src/widgets/qlistview.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -2195,7 +2195,7 @@ void TQListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg,
}
/*!
- Returns the number of pixels of width retquired to draw column \a c
+ Returns the number of pixels of width required to draw column \a c
of list view \a lv, using the metrics \a fm without cropping. The
list view containing this item may use this information depending
on the TQListView::WidthMode settings for the column.
@@ -2833,7 +2833,7 @@ TQListView::~TQListView()
/*!
Calls TQListViewItem::paintCell() and
TQListViewItem::paintBranches() as necessary for all list view
- items that retquire repainting in the \a cw pixels wide and \a ch
+ items that require repainting in the \a cw pixels wide and \a ch
pixels high bounding rectangle starting at position \a cx, \a cy
with offset \a ox, \a oy. Uses the painter \a p.
*/
@@ -6961,7 +6961,7 @@ bool TQListView::rootIsDecorated() const
/*!
Ensures that item \a i is visible, scrolling the list view
vertically if necessary and opening (expanding) any parent items
- if this is retquired to show the item.
+ if this is required to show the item.
\sa itemRect() TQScrollView::ensureVisible()
*/
diff --git a/src/widgets/qlistview.h b/src/widgets/qlistview.h
index f29b2156..02abb51e 100644
--- a/src/widgets/qlistview.h
+++ b/src/widgets/qlistview.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qmainwindow.cpp b/src/widgets/qmainwindow.cpp
index 5b8b6ab3..3da52b6f 100644
--- a/src/widgets/qmainwindow.cpp
+++ b/src/widgets/qmainwindow.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -668,7 +668,7 @@ void TQHideToolTip::maybeTip( const TQPoint &pos )
dock window on the pop up dock window menu. This menu lists the
names of every dock window; visible dock windows have a tick
beside their names. The dock window menu is created automatically
- as retquired by createDockWindowMenu(). Since it may not always be
+ as required by createDockWindowMenu(). Since it may not always be
appropriate for a dock window to appear on this menu the
setAppropriate() function is used to inform the main window
whether or not the dock window menu should include a particular
diff --git a/src/widgets/qmainwindow.h b/src/widgets/qmainwindow.h
index 853e021f..05525937 100644
--- a/src/widgets/qmainwindow.h
+++ b/src/widgets/qmainwindow.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qmenubar.cpp b/src/widgets/qmenubar.cpp
index 3d7082ba..ebe23185 100644
--- a/src/widgets/qmenubar.cpp
+++ b/src/widgets/qmenubar.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -891,7 +891,7 @@ void TQMenuBar::fontChange( const TQFont & f )
negative, it updates the irects member for the current width and
resizes. Otherwise, it does the same calculations for the GIVEN
width and returns the height to which it WOULD have resized. A bit
- tricky, but both operations retquire almost identical steps.
+ tricky, but both operations require almost identical steps.
*/
int TQMenuBar::calculateRects( int max_width )
{
diff --git a/src/widgets/qmenubar.h b/src/widgets/qmenubar.h
index 5bcea545..2878c3dd 100644
--- a/src/widgets/qmenubar.h
+++ b/src/widgets/qmenubar.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qmenudata.cpp b/src/widgets/qmenudata.cpp
index 34fedde7..a5c2c8b0 100644
--- a/src/widgets/qmenudata.cpp
+++ b/src/widgets/qmenudata.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qmenudata.h b/src/widgets/qmenudata.h
index 00f06149..71f9a6cf 100644
--- a/src/widgets/qmenudata.h
+++ b/src/widgets/qmenudata.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qmultilineedit.cpp b/src/widgets/qmultilineedit.cpp
index be5a7aac..affe2feb 100644
--- a/src/widgets/qmultilineedit.cpp
+++ b/src/widgets/qmultilineedit.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -80,7 +80,7 @@
It revealed too much of the internal data structure.
Applications which made normal and reasonable use of TQMultiLineEdit
- should still work without problems. Some odd usage will retquire some
+ should still work without problems. Some odd usage will require some
porting. In these cases, it may be better to use \l TQTextEdit now.
<img src=qmlined-m.png> <img src=qmlined-w.png>
diff --git a/src/widgets/qmultilineedit.h b/src/widgets/qmultilineedit.h
index 50a7c459..16f36abd 100644
--- a/src/widgets/qmultilineedit.h
+++ b/src/widgets/qmultilineedit.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qpopupmenu.cpp b/src/widgets/qpopupmenu.cpp
index 400b89e1..77d7b994 100644
--- a/src/widgets/qpopupmenu.cpp
+++ b/src/widgets/qpopupmenu.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -511,7 +511,7 @@ void TQPopupMenu::popup( const TQPoint &pos, int indexAtPoint )
// TQPopupMenu
// ::exec()
// ::popup()
- // TQPushButton (shouldn't retquire TQMenuPopup)
+ // TQPushButton (shouldn't require TQMenuPopup)
// ::popupPressed
// Some stuff in qwidget.cpp for dialogs... can't remember exactly.
// Also the code here indicatets the parameter should be a rect, not a
diff --git a/src/widgets/qpopupmenu.h b/src/widgets/qpopupmenu.h
index c35bbea7..5e7d10f9 100644
--- a/src/widgets/qpopupmenu.h
+++ b/src/widgets/qpopupmenu.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qprogressbar.cpp b/src/widgets/qprogressbar.cpp
index ed3f8b7b..345038e8 100644
--- a/src/widgets/qprogressbar.cpp
+++ b/src/widgets/qprogressbar.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qprogressbar.h b/src/widgets/qprogressbar.h
index 277c8c93..76463f1e 100644
--- a/src/widgets/qprogressbar.h
+++ b/src/widgets/qprogressbar.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qpushbutton.cpp b/src/widgets/qpushbutton.cpp
index 32e25e76..31641161 100644
--- a/src/widgets/qpushbutton.cpp
+++ b/src/widgets/qpushbutton.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qpushbutton.h b/src/widgets/qpushbutton.h
index 625fbc0e..5824802e 100644
--- a/src/widgets/qpushbutton.h
+++ b/src/widgets/qpushbutton.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qradiobutton.cpp b/src/widgets/qradiobutton.cpp
index 98956c93..39f0e974 100644
--- a/src/widgets/qradiobutton.cpp
+++ b/src/widgets/qradiobutton.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qradiobutton.h b/src/widgets/qradiobutton.h
index 386a6671..6c954631 100644
--- a/src/widgets/qradiobutton.h
+++ b/src/widgets/qradiobutton.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qrangecontrol.cpp b/src/widgets/qrangecontrol.cpp
index 9c437171..a561b3d7 100644
--- a/src/widgets/qrangecontrol.cpp
+++ b/src/widgets/qrangecontrol.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qrangecontrol.h b/src/widgets/qrangecontrol.h
index c683d367..f438ca7a 100644
--- a/src/widgets/qrangecontrol.h
+++ b/src/widgets/qrangecontrol.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qscrollbar.cpp b/src/widgets/qscrollbar.cpp
index 1a2a11c7..e73dc2ed 100644
--- a/src/widgets/qscrollbar.cpp
+++ b/src/widgets/qscrollbar.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qscrollbar.h b/src/widgets/qscrollbar.h
index 08cf4670..c3552cf4 100644
--- a/src/widgets/qscrollbar.h
+++ b/src/widgets/qscrollbar.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qscrollview.cpp b/src/widgets/qscrollview.cpp
index 8c661d1e..03cf1ae1 100644
--- a/src/widgets/qscrollview.cpp
+++ b/src/widgets/qscrollview.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qscrollview.h b/src/widgets/qscrollview.h
index 80b9bbf1..a935f8e3 100644
--- a/src/widgets/qscrollview.h
+++ b/src/widgets/qscrollview.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qslider.cpp b/src/widgets/qslider.cpp
index eaa18d5e..6c1349b7 100644
--- a/src/widgets/qslider.cpp
+++ b/src/widgets/qslider.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qslider.h b/src/widgets/qslider.h
index 7465a943..4d80b4fa 100644
--- a/src/widgets/qslider.h
+++ b/src/widgets/qslider.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qspinbox.cpp b/src/widgets/qspinbox.cpp
index 8bed440f..f92b3ac4 100644
--- a/src/widgets/qspinbox.cpp
+++ b/src/widgets/qspinbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qspinbox.h b/src/widgets/qspinbox.h
index 9faa8357..8bb8dc9a 100644
--- a/src/widgets/qspinbox.h
+++ b/src/widgets/qspinbox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qspinwidget.cpp b/src/widgets/qspinwidget.cpp
index cf960861..080f2ee3 100644
--- a/src/widgets/qspinwidget.cpp
+++ b/src/widgets/qspinwidget.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qsplashscreen.cpp b/src/widgets/qsplashscreen.cpp
index ab528a7a..fe18ebe2 100644
--- a/src/widgets/qsplashscreen.cpp
+++ b/src/widgets/qsplashscreen.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qsplashscreen.h b/src/widgets/qsplashscreen.h
index 628c5d35..9c4660e2 100644
--- a/src/widgets/qsplashscreen.h
+++ b/src/widgets/qsplashscreen.h
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qsplitter.cpp b/src/widgets/qsplitter.cpp
index 90c21b00..7dd3f75e 100644
--- a/src/widgets/qsplitter.cpp
+++ b/src/widgets/qsplitter.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qsplitter.h b/src/widgets/qsplitter.h
index 598ae603..d614bbbe 100644
--- a/src/widgets/qsplitter.h
+++ b/src/widgets/qsplitter.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qstatusbar.cpp b/src/widgets/qstatusbar.cpp
index dc1eda57..c2c8a157 100644
--- a/src/widgets/qstatusbar.cpp
+++ b/src/widgets/qstatusbar.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qstatusbar.h b/src/widgets/qstatusbar.h
index 45ff2e88..9591892f 100644
--- a/src/widgets/qstatusbar.h
+++ b/src/widgets/qstatusbar.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qsyntaxhighlighter.cpp b/src/widgets/qsyntaxhighlighter.cpp
index 061d9c53..bf8938bb 100644
--- a/src/widgets/qsyntaxhighlighter.cpp
+++ b/src/widgets/qsyntaxhighlighter.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -103,7 +103,7 @@ TQSyntaxHighlighter::~TQSyntaxHighlighter()
In your reimplementation you should parse the paragraph's \a text
and call setFormat() as often as necessary to apply any font and
- color changes that you retquire. Your function must return a value
+ color changes that you require. Your function must return a value
which indicates the paragraph's end state: see below.
Some syntaxes can have constructs that span paragraphs. For
diff --git a/src/widgets/qsyntaxhighlighter.h b/src/widgets/qsyntaxhighlighter.h
index 7b3d726d..19d16f7c 100644
--- a/src/widgets/qsyntaxhighlighter.h
+++ b/src/widgets/qsyntaxhighlighter.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qsyntaxhighlighter_p.h b/src/widgets/qsyntaxhighlighter_p.h
index 067e3e38..28f7fa84 100644
--- a/src/widgets/qsyntaxhighlighter_p.h
+++ b/src/widgets/qsyntaxhighlighter_p.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtabbar.cpp b/src/widgets/qtabbar.cpp
index d66790f3..e86ff041 100644
--- a/src/widgets/qtabbar.cpp
+++ b/src/widgets/qtabbar.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtabbar.h b/src/widgets/qtabbar.h
index 48f76aeb..408632a1 100644
--- a/src/widgets/qtabbar.h
+++ b/src/widgets/qtabbar.h
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtabwidget.cpp b/src/widgets/qtabwidget.cpp
index 2c85a611..0621f0e3 100644
--- a/src/widgets/qtabwidget.cpp
+++ b/src/widgets/qtabwidget.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtabwidget.h b/src/widgets/qtabwidget.h
index 6219528b..9110af88 100644
--- a/src/widgets/qtabwidget.h
+++ b/src/widgets/qtabwidget.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtextbrowser.cpp b/src/widgets/qtextbrowser.cpp
index 9cd88a02..984f6675 100644
--- a/src/widgets/qtextbrowser.cpp
+++ b/src/widgets/qtextbrowser.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtextbrowser.h b/src/widgets/qtextbrowser.h
index 5a245b4e..12f8fb83 100644
--- a/src/widgets/qtextbrowser.h
+++ b/src/widgets/qtextbrowser.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtextedit.h b/src/widgets/qtextedit.h
index ae3c8ee4..ac334a58 100644
--- a/src/widgets/qtextedit.h
+++ b/src/widgets/qtextedit.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtextview.cpp b/src/widgets/qtextview.cpp
index 59db4d9c..3aa44452 100644
--- a/src/widgets/qtextview.cpp
+++ b/src/widgets/qtextview.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtextview.h b/src/widgets/qtextview.h
index 68378a02..75c7c3a1 100644
--- a/src/widgets/qtextview.h
+++ b/src/widgets/qtextview.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtitlebar.cpp b/src/widgets/qtitlebar.cpp
index ceec9825..fc607b08 100644
--- a/src/widgets/qtitlebar.cpp
+++ b/src/widgets/qtitlebar.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtitlebar_p.h b/src/widgets/qtitlebar_p.h
index 25b66a70..27a9871e 100644
--- a/src/widgets/qtitlebar_p.h
+++ b/src/widgets/qtitlebar_p.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtoolbar.cpp b/src/widgets/qtoolbar.cpp
index 0b700573..c2833189 100644
--- a/src/widgets/qtoolbar.cpp
+++ b/src/widgets/qtoolbar.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtoolbar.h b/src/widgets/qtoolbar.h
index 3d60fd5e..894f2afa 100644
--- a/src/widgets/qtoolbar.h
+++ b/src/widgets/qtoolbar.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtoolbox.cpp b/src/widgets/qtoolbox.cpp
index 86441878..dd7d59e8 100644
--- a/src/widgets/qtoolbox.cpp
+++ b/src/widgets/qtoolbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtoolbox.h b/src/widgets/qtoolbox.h
index d5ee685f..717200be 100644
--- a/src/widgets/qtoolbox.h
+++ b/src/widgets/qtoolbox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtoolbutton.cpp b/src/widgets/qtoolbutton.cpp
index ac14adc1..7243e8e8 100644
--- a/src/widgets/qtoolbutton.cpp
+++ b/src/widgets/qtoolbutton.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtoolbutton.h b/src/widgets/qtoolbutton.h
index 44263247..ce187e8a 100644
--- a/src/widgets/qtoolbutton.h
+++ b/src/widgets/qtoolbutton.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qtooltip.cpp b/src/widgets/qtooltip.cpp
index f121a38e..e61707f5 100644
--- a/src/widgets/qtooltip.cpp
+++ b/src/widgets/qtooltip.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -715,7 +715,7 @@ void TQTipManager::setWakeUpDelay ( int i )
can supply a \c{TQToolTipGroup *} and another text if you want.
Both of these are one-liners and cover the majority of cases. The
- third and most general way to use TQToolTip retquires you to
+ third and most general way to use TQToolTip requires you to
reimplement a pure virtual function to decide whether to pop up a
tool tip. The \c tooltip/tooltip.cpp example demonstrates this
too. This mode can be used to implement tips for text that can
diff --git a/src/widgets/qtooltip.h b/src/widgets/qtooltip.h
index 5efe98e6..37f91e5f 100644
--- a/src/widgets/qtooltip.h
+++ b/src/widgets/qtooltip.h
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qvalidator.cpp b/src/widgets/qvalidator.cpp
index d560205d..b5df08e9 100644
--- a/src/widgets/qvalidator.cpp
+++ b/src/widgets/qvalidator.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -64,7 +64,7 @@
\c Invalid, \c Intermediate or \c Acceptable depending on whether
its argument is valid (for the subclass's definition of valid).
- These three states retquire some explanation. An \c Invalid string
+ These three states require some explanation. An \c Invalid string
is \e clearly invalid. \c Intermediate is less obvious: the
concept of validity is slippery when the string is incomplete
(still being edited). TQValidator defines \c Intermediate as the
diff --git a/src/widgets/qvalidator.h b/src/widgets/qvalidator.h
index e693d98a..b24c9498 100644
--- a/src/widgets/qvalidator.h
+++ b/src/widgets/qvalidator.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qvbox.cpp b/src/widgets/qvbox.cpp
index 7150a55d..a80e952d 100644
--- a/src/widgets/qvbox.cpp
+++ b/src/widgets/qvbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qvbox.h b/src/widgets/qvbox.h
index c50721bb..3558997c 100644
--- a/src/widgets/qvbox.h
+++ b/src/widgets/qvbox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qvbuttongroup.cpp b/src/widgets/qvbuttongroup.cpp
index 30225261..79dc9ea2 100644
--- a/src/widgets/qvbuttongroup.cpp
+++ b/src/widgets/qvbuttongroup.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qvbuttongroup.h b/src/widgets/qvbuttongroup.h
index 7660989b..8f17ce1c 100644
--- a/src/widgets/qvbuttongroup.h
+++ b/src/widgets/qvbuttongroup.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qvgroupbox.cpp b/src/widgets/qvgroupbox.cpp
index 9ccecb53..5f8b235e 100644
--- a/src/widgets/qvgroupbox.cpp
+++ b/src/widgets/qvgroupbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qvgroupbox.h b/src/widgets/qvgroupbox.h
index 9edc7f9e..e00db426 100644
--- a/src/widgets/qvgroupbox.h
+++ b/src/widgets/qvgroupbox.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qwhatsthis.cpp b/src/widgets/qwhatsthis.cpp
index baa9f11f..50c75fff 100644
--- a/src/widgets/qwhatsthis.cpp
+++ b/src/widgets/qwhatsthis.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qwhatsthis.h b/src/widgets/qwhatsthis.h
index 0c68159c..365e673c 100644
--- a/src/widgets/qwhatsthis.h
+++ b/src/widgets/qwhatsthis.h
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qwidgetinterface_p.h b/src/widgets/qwidgetinterface_p.h
index 7d2864e2..128a2771 100644
--- a/src/widgets/qwidgetinterface_p.h
+++ b/src/widgets/qwidgetinterface_p.h
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qwidgetplugin.cpp b/src/widgets/qwidgetplugin.cpp
index d0d34a46..1cd2434d 100644
--- a/src/widgets/qwidgetplugin.cpp
+++ b/src/widgets/qwidgetplugin.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -165,7 +165,7 @@ TQRESULT TQWidgetPluginPrivate::queryInterface( const TQUuid &iid, TQUnknownInte
\fn TQWidget *TQWidgetPlugin::create( const TQString &, TQWidget *, const char * )
Creates and returns a TQWidget object for the widget key \a key.
- The widget key is the class name of the retquired widget. The \a
+ The widget key is the class name of the required widget. The \a
name and \a parent arguments are passed to the custom widget's
constructor.
diff --git a/src/widgets/qwidgetplugin.h b/src/widgets/qwidgetplugin.h
index 86167f51..0163e00f 100644
--- a/src/widgets/qwidgetplugin.h
+++ b/src/widgets/qwidgetplugin.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qwidgetresizehandler.cpp b/src/widgets/qwidgetresizehandler.cpp
index 6ce1e778..2dd5383e 100644
--- a/src/widgets/qwidgetresizehandler.cpp
+++ b/src/widgets/qwidgetresizehandler.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qwidgetresizehandler_p.h b/src/widgets/qwidgetresizehandler_p.h
index 89c5a0d7..676b5365 100644
--- a/src/widgets/qwidgetresizehandler_p.h
+++ b/src/widgets/qwidgetresizehandler_p.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qwidgetstack.cpp b/src/widgets/qwidgetstack.cpp
index 5f770712..72d9e1e1 100644
--- a/src/widgets/qwidgetstack.cpp
+++ b/src/widgets/qwidgetstack.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qwidgetstack.h b/src/widgets/qwidgetstack.h
index 63e3d8a3..466ce2cb 100644
--- a/src/widgets/qwidgetstack.h
+++ b/src/widgets/qwidgetstack.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/widgets/qlineedit.cpp b/src/widgets/qlineedit.cpp
index 0546bb0d..2a4ef1c4 100644
--- a/src/widgets/qlineedit.cpp
+++ b/src/widgets/qlineedit.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -1123,17 +1123,17 @@ bool TQLineEdit::hasAcceptableInput() const
The mask format understands these mask characters:
\table
\header \i Character \i Meaning
- \row \i \c A \i ASCII alphabetic character retquired. A-Z, a-z.
- \row \i \c a \i ASCII alphabetic character permitted but not retquired.
- \row \i \c N \i ASCII alphanumeric character retquired. A-Z, a-z, 0-9.
- \row \i \c n \i ASCII alphanumeric character permitted but not retquired.
- \row \i \c X \i Any character retquired.
- \row \i \c x \i Any character permitted but not retquired.
- \row \i \c 9 \i ASCII digit retquired. 0-9.
- \row \i \c 0 \i ASCII digit permitted but not retquired.
- \row \i \c D \i ASCII digit retquired. 1-9.
- \row \i \c d \i ASCII digit permitted but not retquired (1-9).
- \row \i \c # \i ASCII digit or plus/minus sign permitted but not retquired.
+ \row \i \c A \i ASCII alphabetic character required. A-Z, a-z.
+ \row \i \c a \i ASCII alphabetic character permitted but not required.
+ \row \i \c N \i ASCII alphanumeric character required. A-Z, a-z, 0-9.
+ \row \i \c n \i ASCII alphanumeric character permitted but not required.
+ \row \i \c X \i Any character required.
+ \row \i \c x \i Any character permitted but not required.
+ \row \i \c 9 \i ASCII digit required. 0-9.
+ \row \i \c 0 \i ASCII digit permitted but not required.
+ \row \i \c D \i ASCII digit required. 1-9.
+ \row \i \c d \i ASCII digit permitted but not required (1-9).
+ \row \i \c # \i ASCII digit or plus/minus sign permitted but not required.
\row \i \c > \i All following alphabetic characters are uppercased.
\row \i \c < \i All following alphabetic characters are lowercased.
\row \i \c ! \i Switch off case conversion.
@@ -1971,7 +1971,7 @@ void TQLineEdit::drawContents( TQPainter *p )
// IMCompose event. Although the function is invoked from various
// other points, some situations such as "candidate selection on
// AlignHCenter'ed text" need this invocation because
- // updateMicroFocusHint() retquires updated contentsRect(), and
+ // updateMicroFocusHint() requires updated contentsRect(), and
// there are no other chances in such situation that invoke the
// function.
d->updateMicroFocusHint();
@@ -2419,8 +2419,8 @@ void TQLineEditPrivate::updateMicroFocusHint()
{
// To reduce redundant microfocus update notification, we remember
// the old rect and update the microfocus if actual update is
// retquired. The rect o is intentionally static because some
// notifyee retquires the microfocus information as global update
// rather than per notifyee update to place shared widget around
// microfocus.
static TQRect o;
@@ -2419,8 +2419,8 @@ void TQLineEditPrivate::updateMicroFocusHint()
// To reduce redundant microfocus update notification, we remember
// the old rect and update the microfocus if actual update is
- // retquired. The rect o is intentionally static because some
- // notifyee retquires the microfocus information as global update
+ // required. The rect o is intentionally static because some
+ // notifyee requires the microfocus information as global update
// rather than per notifyee update to place shared widget around
// microfocus.
diff --git a/src/widgets/qlistbox.cpp b/src/widgets/qlistbox.cpp
index 31485527..c8ca44c9 100644
--- a/src/widgets/qlistbox.cpp
+++ b/src/widgets/qlistbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -835,7 +835,7 @@ int TQListBoxPixmap::rtti() const
setCurrentItem().
The list box normally arranges its items in a single column and
- adds a vertical scroll bar if retquired. It is possible to have a
+ adds a vertical scroll bar if required. It is possible to have a
different fixed number of columns (setColumnMode()), or as many
columns as will fit in the list box's assigned screen space
(setColumnMode(FitToWidth)), or to have a fixed number of rows
@@ -963,8 +963,8 @@ int TQListBoxPixmap::rtti() const
\value FitToHeight There are as many rows as will fit on-screen.
- \value Variable There are as many rows as are retquired by the
- column mode. (Or as many columns as retquired by the row mode.)
+ \value Variable There are as many rows as are required by the
+ column mode. (Or as many columns as required by the row mode.)
Example: When you call setRowMode( FitToHeight ), columnMode()
automatically becomes \c Variable to accommodate the row mode
@@ -2317,7 +2317,7 @@ void TQListBox::mouseMoveEvent( TQMouseEvent *e )
d->scrollTimer->start( 100, FALSE );
doAutoScroll();
} else if ( !d->scrollTimer ) {
// or just select the retquired bits
updateSelection();
}
}
@@ -2317,7 +2317,7 @@ void TQListBox::mouseMoveEvent( TQMouseEvent *e )
doAutoScroll();
} else if ( !d->scrollTimer ) {
- // or just select the retquired bits
+ // or just select the required bits
updateSelection();
}
diff --git a/src/widgets/qtextedit.cpp b/src/widgets/qtextedit.cpp
index 09466f45..e2a78743 100644
--- a/src/widgets/qtextedit.cpp
+++ b/src/widgets/qtextedit.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -1089,7 +1089,7 @@ void TQTextEdit::drawContents( TQPainter *p, int cx, int cy, int cw, int ch )
}
}
// This invocation is retquired to follow dragging of active window
// by the showed candidate window.
updateMicroFocusHint();
}
@@ -5901,7 +5901,7 @@ void TQTextEdit::setReadOnly( bool b )
/*!
Scrolls to the bottom of the document and does formatting if
- retquired.
+ required.
*/
void TQTextEdit::scrollToBottom()
@@ -1089,7 +1089,7 @@ void TQTextEdit::drawContents( TQPainter *p, int cx, int cy, int cw, int ch )
}
}
- // This invocation is retquired to follow dragging of active window
+ // This invocation is required to follow dragging of active window
// by the showed candidate window.
updateMicroFocusHint();